#
#  Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# == Schema Information
# Schema version: 17
#
# Table name: comments
#
#  id         :integer(11)     not null, primary key
#  user_id    :integer(11)     
#  event_id   :integer(11)     
#  rating     :integer(11)     
#  comment    :text            
#  created_at :datetime        
#  updated_at :datetime        
#

class Comment < ActiveRecord::Base
  
  belongs_to :user
  belongs_to :event
  
  validates_presence_of :user_id, :event_id, :comment, :rating
  validates_numericality_of :rating, :only_integer => true, :message => "must be an integer number"
  validates_inclusion_of :rating, :in => 0..5, :message => "must be between 0 and 5"
  
  def author
    self.user
  end
  
end
